Index: trunk/psModules/src/camera/pmFPARead.h
===================================================================
--- trunk/psModules/src/camera/pmFPARead.h	(revision 18163)
+++ trunk/psModules/src/camera/pmFPARead.h	(revision 21363)
@@ -4,6 +4,6 @@
  * @author Paul Price, IfA
  *
- * @version $Revision: 1.15 $ $Name: not supported by cvs2svn $
- * @date $Date: 2008-06-17 22:16:38 $
+ * @version $Revision: 1.16 $ $Name: not supported by cvs2svn $
+ * @date $Date: 2009-02-06 02:31:24 $
  * Copyright 2005-2006 Institute for Astronomy, University of Hawaii
  */
@@ -60,9 +60,9 @@
                        int numRows,      // The number of rows to read
                        pmConfig *config
-                      );
+    );
 
 /// Return the number of readouts within a cell
 ///
 /// This function is type-independent (doesn't matter if you are interested in the image/mask/weight).
 int pmCellNumReadouts(pmCell *cell, psFits *fits, pmConfig *config);
 
@@ -74,5 +74,5 @@
                 psFits *fits,           // FITS file from which to read
                 pmConfig *config        // Configuration
-               );
+    );
 
 /// Read a chip
@@ -82,5 +82,5 @@
                 psFits *fits,           // FITS file from which to read
                 pmConfig *config        // Configuration
-               );
+    );
 
 /// Read an FPA
@@ -90,5 +90,5 @@
                psFits *fits,            // FITS file from which to read
                pmConfig *config         // Configuration
-              );
+    );
 
 // Mask functions follow
@@ -126,5 +126,5 @@
                     psFits *fits,       // FITS file from which to read
                     pmConfig *config    // Configuration
-                   );
+    );
 
 /// Read an entire chip into the mask
@@ -134,5 +134,5 @@
                     psFits *fits,       // FITS file from which to read
                     pmConfig *config    // Configuration
-                   );
+    );
 
 /// Read an entire FPA into the mask
@@ -142,57 +142,57 @@
                    psFits *fits,        // FITS file from which to read
                    pmConfig *config     // Configuration
-                  );
-
-// Weight functions follow
-
-/// Check to see if there is more to read when reading a readout incrementally into the weight
-bool pmReadoutMoreWeight(pmReadout *readout, ///< Readout of interest
-                         psFits *fits,  ///< FITS file from which to read
-                         int z,         ///< Readout number/plane; zero-offset indexing
-                         int numScans,  ///< Number of scans (rows/cols) to read
-                         pmConfig *config ///< Configuration
-    );
-
-/// Read a chunk of a readout into the weight
+    );
+
+// Variance functions follow
+
+/// Check to see if there is more to read when reading a readout incrementally into the variance
+bool pmReadoutMoreVariance(pmReadout *readout, ///< Readout of interest
+                           psFits *fits, ///< FITS file from which to read
+                           int z,       ///< Readout number/plane; zero-offset indexing
+                           int numScans, ///< Number of scans (rows/cols) to read
+                           pmConfig *config ///< Configuration
+    );
+
+/// Read a chunk of a readout into the variance
 ///
 /// Allows reading the readout incrementally
-bool pmReadoutReadChunkWeight(pmReadout *readout, ///< Readout of interest
-                              psFits *fits, ///< FITS file from which to read
-                              int z,    ///< Readout number/plane; zero-offset indexing
-                              int numScans, ///< Number of scans (rows/cols) to read
-                              int overlap, ///< Overlap between consecutive reads
-                              pmConfig *config ///< Configuration
-    );
-
-/// Read the entire readout into the weight
-bool pmReadoutReadWeight(pmReadout *readout, ///< Readout of interest
-                         psFits *fits,  ///< FITS file from which to read
-                         int z,         ///< Readout number/plane; zero-offset indexing
-                         pmConfig *config ///< Configuration
-    );
-
-/// Read an entire cell into the weight
-///
-/// Same as pmCellRead, but reads into the weight element of the readouts.
-bool pmCellReadWeight(pmCell *cell,     // Cell to read into
-                      psFits *fits,     // FITS file from which to read
-                      pmConfig *config  // Configuration
-                     );
-
-/// Read an entire chip into the weight
-///
-/// Same as pmChipRead, but reads into the weight element of the readouts.
-bool pmChipReadWeight(pmChip *chip,     // Chip to read into
-                      psFits *fits,     // FITS file from which to read
-                      pmConfig *config  // Configuration
-                     );
-
-/// Read an entire FPA into the weight
-///
-/// Same as pmFPARead, but reads into the weight element of the readouts.
-bool pmFPAReadWeight(pmFPA *fpa,        // FPA to read into
-                     psFits *fits,      // FITS file from which to read
-                     pmConfig *config   // Configuration
-                    );
+bool pmReadoutReadChunkVariance(pmReadout *readout, ///< Readout of interest
+                                psFits *fits, ///< FITS file from which to read
+                                int z,    ///< Readout number/plane; zero-offset indexing
+                                int numScans, ///< Number of scans (rows/cols) to read
+                                int overlap, ///< Overlap between consecutive reads
+                                pmConfig *config ///< Configuration
+    );
+
+/// Read the entire readout into the variance
+bool pmReadoutReadVariance(pmReadout *readout, ///< Readout of interest
+                           psFits *fits,  ///< FITS file from which to read
+                           int z,         ///< Readout number/plane; zero-offset indexing
+                           pmConfig *config ///< Configuration
+    );
+
+/// Read an entire cell into the variance
+///
+/// Same as pmCellRead, but reads into the variance element of the readouts.
+bool pmCellReadVariance(pmCell *cell,     // Cell to read into
+                        psFits *fits,     // FITS file from which to read
+                        pmConfig *config  // Configuration
+    );
+
+/// Read an entire chip into the variance
+///
+/// Same as pmChipRead, but reads into the variance element of the readouts.
+bool pmChipReadVariance(pmChip *chip,     // Chip to read into
+                        psFits *fits,     // FITS file from which to read
+                        pmConfig *config  // Configuration
+    );
+
+/// Read an entire FPA into the variance
+///
+/// Same as pmFPARead, but reads into the variance element of the readouts.
+bool pmFPAReadVariance(pmFPA *fpa,        // FPA to read into
+                       psFits *fits,      // FITS file from which to read
+                       pmConfig *config   // Configuration
+    );
 
 /// Read cell headers
@@ -226,5 +226,5 @@
 /// also read and included in the cell analysis metadata under "name.HEADER".
 int pmCellReadTable(pmCell *cell,       ///< Cell for which to read table
-                    psFits *fits,       ///< FITS file from which the table
+                    psFits *fits,       ///< FITS file from which to read the table
                     const char *name    ///< Specifies the extension name, and target in the analysis metadata
                    );
@@ -233,6 +233,6 @@
 ///
 /// Iterates over component cells, calling pmCellReadTable.
-int pmChipReadTable(pmChip *chip,       ///< Cell for which to read table
-                    psFits *fits,       ///< FITS file from which the table
+int pmChipReadTable(pmChip *chip,       ///< Chip for which to read table
+                    psFits *fits,       ///< FITS file from which to read the table
                     const char *name    ///< Specifies the extension name, and target in the analysis metadata
                    );
@@ -241,8 +241,26 @@
 ///
 /// Iterates over component chips, calling pmChipReadTable.
-int pmFPAReadTable(pmFPA *fpa,          ///< Cell for which to read table
-                   psFits *fits,        ///< FITS file from which the table
+int pmFPAReadTable(pmFPA *fpa,          ///< FPA for which to read table
+                   psFits *fits,        ///< FITS file from which to read the table
                    const char *name     ///< Specifies the extension name, and target in the analysis metadata
                   );
+
+/// Read covariance matrices for a cell
+bool pmCellReadCovariance(pmCell *cell, ///< Cell for which to read covariance matrices
+                          psFits *fits  ///< FITS file from which to read
+    );
+
+/// Read covariance matrices for a chip
+bool pmChipReadCovariance(pmChip *chip, ///< Chip for which to read covariance matrices
+                          psFits *fits  ///< FITS file from which to read
+    );
+
+/// Read covariance matrices for a cell
+bool pmFPAReadCovariance(pmFPA *fpa,    ///< FPA for which to read covariance matrices
+                         psFits *fits   ///< FITS file from which to read
+    );
+
+
+
 /// @}
 #endif
@@ -60,9 +60,9 @@
 /// Return the number of readouts within a cell
 ///
-/// This function is type-independent (doesn't matter if you are interested in the image/mask/weight).
+/// This function is type-independent (doesn't matter if you are interested in the image/mask/variance).
 int pmCellNumReadouts(pmCell *cell, psFits *fits, pmConfig *config);
 
